A PlatformInterface mixin that can be combined with fake or mock objects,
such as test's Fake or mockito's Mock.
It passes the PlatformInterface.verify check even though it isn't
using extends.
This class is intended for use in tests only.
Sample usage (assuming UrlLauncherPlatform extends PlatformInterface):
class UrlLauncherPlatformMock extends Mock
with MockPlatformInterfaceMixin
implements UrlLauncherPlatform {}
- Implemented types
- Annotations
-
- @visibleForTesting
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited